/*  Glimmer - linebar.h
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _LINE_BAR_H_
#define _LINE_BAR_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "declarations.h"

void make_line_toolbar(void);
void execute_line_cb(GtkWidget* widget, gpointer data);
void line_combo_set_history(GList *history);
gboolean line_combo_add_string(gchar *string);

extern GtkWidget *linebar;
extern GtkWidget *line_combo;
extern GtkWidget *line_entry;

#ifdef __cplusplus
}
#endif

#endif
